# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions

from .custom_payment_method_update_request import CustomPaymentMethodUpdateRequest


class PaymentMethodUpdateRequest_Custom(CustomPaymentMethodUpdateRequest):
    type: typing_extensions.Literal["custom"]

    class Config:
        frozen = True
        allow_population_by_field_name = True


PaymentMethodUpdateRequest = typing.Union[PaymentMethodUpdateRequest_Custom]
