# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ....core.datetime_utils import serialize_datetime


class EntityUserRequest(pydantic.BaseModel):
    foreign_id: typing.Optional[str] = pydantic.Field(alias="foreignId")
    email: typing.Optional[str]
    name: typing.Optional[str]
    roles: typing.Optional[typing.List[str]] = pydantic.Field(
        description=('List of roles. A role can be any string. For example: "payer", "approver", "viewer"\n')
    )

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        allow_population_by_field_name = True
        json_encoders = {dt.datetime: serialize_datetime}
